@@ -1,5 +1,5 @@
 # file eulxml/xmlmap/core.py
-# 
+#
 #   Copyright 2010,2011 Emory University Libraries
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
@@ -23,12 +23,12 @@ import warnings
 from lxml import etree
 from lxml.builder import ElementMaker
 
-from eulxml.xmlmap.fields import Field, NodeList
+from eulxml.xmlmap.fields import Field
 
 logger = logging.getLogger(__name__)
 
-__all__ = [ 'XmlObject', 'parseUri', 'parseString', 'loadSchema',
-    'load_xmlobject_from_string', 'load_xmlobject_from_file' ]
+__all__ = ['XmlObject', 'parseUri', 'parseString', 'loadSchema',
+    'load_xmlobject_from_string', 'load_xmlobject_from_file']
 
 # NB: When parsing XML in this module, we explicitly create a new parser
 #   each time. Without this, lxml 2.2.7 uses a global default parser. When
@@ -45,10 +45,13 @@ __all__ = [ 'XmlObject', 'parseUri', 'parseString', 'loadSchema',
 #   This lxml behavior has been logged as a bug:
 #   https://bugs.launchpad.net/lxml/+bug/673205
 
+
 def parseUri(stream, uri=None):
     """Read an XML document from a URI, and return a :mod:`lxml.etree`
     document."""
     return etree.parse(stream, parser=_get_xmlparser(), base_url=uri)
+
+
 def parseString(string, uri=None):
     """Read an XML document provided as a byte string, and return a
     :mod:`lxml.etree` document. String cannot be a Unicode string.
@@ -57,10 +60,12 @@ def parseString(string, uri=None):
 
 # internal cache for loaded schemas, so we only load each schema once
 _loaded_schemas = {}
+
+
 def loadSchema(uri, base_uri=None, override_proxy_requirement=False):
     """Load an XSD XML document (specified by filename or URL), and return a
     :class:`lxml.etree.XMLSchema`.
-    
+
     Note that frequently loading a schema without using a web proxy may
     introduce significant network resource usage as well as instability if
     the schema becomes unavailable. Thus this function will fail if the
@@ -70,7 +75,7 @@ def loadSchema(uri, base_uri=None, override_proxy_requirement=False):
     # uri to use for reporting errors - include base uri if any
     if uri in _loaded_schemas:
         return _loaded_schemas[uri]
-    
+
     error_uri = uri
     if base_uri is not None:
         error_uri += ' (base URI %s)' % base_uri
@@ -80,7 +85,7 @@ def loadSchema(uri, base_uri=None, override_proxy_requirement=False):
     if 'HTTP_PROXY' not in os.environ and _http_uri(uri):
         message = ('Loading schema %s without a web proxy may introduce ' +
                    'significant network resource usage as well as ' +
-                   'instability if that server becomes inaccessible. ' + 
+                   'instability if that server becomes inaccessible. ' +
                    'The HTTP_PROXY environment variable is required ' +
                    'for loading schemas.  Schema validation will be disabled.') \
                   % (error_uri,)
@@ -107,9 +112,12 @@ def loadSchema(uri, base_uri=None, override_proxy_requirement=False):
     except etree.XMLSchemaParseError as parse_err:
         # re-raise as a schema parse error, but ensure includes details about schema being loaded
         raise etree.XMLSchemaParseError('Failed to parse schema %s -- %s' % (error_uri, parse_err))
+
+
 def _http_uri(uri):
     return uri.startswith('http:') or uri.startswith('https:')
 
+
 class _FieldDescriptor(object):
     def __init__(self, field):
         self.field = field
@@ -119,7 +127,7 @@ class _FieldDescriptor(object):
             return self
         return self.field.get_for_node(obj.node, obj.context)
 
-    def __set__(self, obj, value):        
+    def __set__(self, obj, value):
         return self.field.set_for_node(obj.node, obj.context, value)
 
     def __delete__(self, obj):
@@ -179,7 +187,7 @@ class XmlObjectType(type):
                             # otherwise, use nearest parent xsd
                             else:
                                 schema_obj = load_xmlobject_from_file(base_xsd, XsdSchema)
-                        
+
                         attr_val = attr_val.get_field(schema_obj)
                 field = attr_val
                 fields[attr_name] = field
@@ -229,6 +237,7 @@ class XmlObjectType(type):
         create_field.__name__ = field_name
         return create_field
 
+
 class XmlObject(object):
 
     """
@@ -283,7 +292,7 @@ class XmlObject(object):
     '''Override for schema validation; if a schema must be defined for
      the use of :class:`xmlmap.fields.SchemaField` for a sub-xmlobject
      that should not be validated, set to False.'''
-    
+
     @property
     def xmlschema(self):
         """A parsed XSD schema instance of
@@ -293,14 +302,14 @@ class XmlObject(object):
         schema at class definition time, instead of at class instance
         initialization time, you may want to define your schema in
         your subclass like this::
-        
+
           XSD_SCHEMA = "http://www.openarchives.org/OAI/2.0/oai_dc.xsd"
           xmlschema = xmlmap.loadSchema(XSD_SCHEMA)
-          
+
         """
         if self.XSD_SCHEMA:
             return loadSchema(self.XSD_SCHEMA)
-    
+
     # NOTE: DTD and RNG validation could be handled similarly to XSD validation logic
 
     def __init__(self, node=None, context=None, **kwargs):
@@ -318,7 +327,8 @@ class XmlObject(object):
             nsmap = {}
 
         # xpath has no notion of a default namespace - omit any namespace with no prefix
-        self.context = {'namespaces': dict([(prefix, ns) for prefix, ns in nsmap.iteritems() if prefix ]) }
+        self.context = {'namespaces': dict([(prefix, ns) for prefix, ns
+                                            in nsmap.iteritems() if prefix])}
 
         if context is not None:
             self.context.update(context)
@@ -340,7 +350,6 @@ class XmlObject(object):
         E = ElementMaker(**opts)
         root = E(self.ROOT_NAME)
         return root
-        
 
     def xsl_transform(self, filename=None, xsl=None, return_type=None, **params):
         """Run an xslt transform on the contents of the XmlObject.
@@ -365,7 +374,16 @@ class XmlObject(object):
         # - to output xml result, use serialize instead of unicode
         if return_type is None:
             return_type = XmlObject
-        return return_type(transform(self.node))
+
+        result = transform(self.node)
+        # If XSLT returns nothing, transform returns an _XSLTResultTree
+        # with no root node.  Log a warning, and don't generate an
+        # empty xmlobject which will behave unexpectedly.
+        if result is None or result.getroot() is None:
+            logger.warning("XSL transform generated an empty result")
+        else:
+            # pass in root node, rather than the result tree object
+            return return_type(result.getroot())
 
     def __unicode__(self):
         if isinstance(self.node, basestring):
@@ -448,7 +466,7 @@ class XmlObject(object):
         if the xml is schema valid or no schema is defined.  If a
         schema is defined but :attr:`schema_validate` is False, schema
         validation will be skipped.
-        
+
         Currently only supports schema validation.
 
         :rtype: list
@@ -466,6 +484,11 @@ class XmlObject(object):
         :raises: Exception if no XSD schema is defined for this XmlObject instance
         """
         if self.xmlschema is not None:
+            # clear out errors so they are not duplicated by repeated
+            # validations on the same schema object
+            self.xmlschema._clear_error_log()
+            # NOTE: _clear_error_log is technically private, but I can't find
+            # any public method to clear the validation log.
             return self.xmlschema.validate(self.node)
         else:
             raise Exception('No XSD schema is defined, cannot validate document')
@@ -474,7 +497,7 @@ class XmlObject(object):
         """
         Retrieve any validation errors that occured during schema validation
         done via :meth:`is_valid`.
-        
+
         :returns: a list of :class:`lxml.etree._LogEntry` instances
         :raises: Exception if no XSD schema is defined for this XmlObject instance
         """
@@ -489,7 +512,8 @@ class XmlObject(object):
         attributes, and no text. Returns False if any are present.
         """
         return len(self.node) == 0 and len(self.node.attrib) == 0 \
-            and not self.node.text and not self.node.tail # regular text or text after a node
+            and not self.node.text and not self.node.tail  # regular text or text after a node
+
 
 class Urllib2Resolver(etree.Resolver):
     def resolve(self, url, public_id, context):
@@ -502,6 +526,7 @@ class Urllib2Resolver(etree.Resolver):
         return self.resolve_file(f, context, base_url=url)
 _defaultResolver = Urllib2Resolver()
 
+
 def _get_xmlparser(xmlclass=XmlObject, validate=False, resolver=_defaultResolver):
     """Initialize an instance of :class:`lxml.etree.XMLParser` with appropriate
     settings for validation.  If validation is requested and the specified
@@ -520,18 +545,19 @@ def _get_xmlparser(xmlclass=XmlObject, validate=False, resolver=_defaultResolver
             opts = {'schema': xmlschema}
         else:
             # if configured XmlObject does not have a schema defined, assume DTD validation
-            opts = {'dtd_validation': True}    
+            opts = {'dtd_validation': True}
     else:
         # if validation is not requested, no parser options are needed
         opts = {}
 
     parser = etree.XMLParser(**opts)
-    
+
     if resolver is not None:
         parser.resolvers.add(resolver)
-        
+
     return parser
 
+
 def load_xmlobject_from_string(string, xmlclass=XmlObject, validate=False,
         resolver=None):
     """Initialize an XmlObject from a string.
@@ -550,7 +576,7 @@ def load_xmlobject_from_string(string, xmlclass=XmlObject, validate=False,
     :param validate: boolean, enable validation; defaults to false
     :rtype: instance of :class:`~eulxml.xmlmap.XmlObject` requested
     """
-    parser = _get_xmlparser(xmlclass=xmlclass, validate=validate, resolver=resolver)    
+    parser = _get_xmlparser(xmlclass=xmlclass, validate=validate, resolver=resolver)
     element = etree.fromstring(string, parser)
     return xmlclass(element)
 
@@ -566,7 +592,7 @@ def load_xmlobject_from_file(filename, xmlclass=XmlObject, validate=False,
     :param filename: name of the file that should be loaded as an xmlobject.
         :meth:`etree.lxml.parse` will accept a file name/path, a file object, a
         file-like object, or an HTTP or FTP url, however file path and URL are
-        recommended, as they are generally faster for lxml to handle.    
+        recommended, as they are generally faster for lxml to handle.
     """
     parser = _get_xmlparser(xmlclass=xmlclass, validate=validate, resolver=resolver)
 
@@ -580,6 +606,7 @@ from eulxml.xmlmap.fields import *
 # XSD schema xmlobjects - used in XmlObjectType to process SchemaFields
 # FIXME: where should these actually go? depends on both XmlObject and fields
 
+
 class XsdType(XmlObject):
     ROOT_NAME = 'simpleType'
     name = StringField('@name')
@@ -594,12 +621,12 @@ class XsdType(XmlObject):
         else:
             basetype = self.base
         return basetype
-    
+
 
 class XsdSchema(XmlObject):
     ROOT_NAME = 'schema'
     ROOT_NS = 'http://www.w3.org/2001/XMLSchema'
-    ROOT_NAMESPACES = {'xs': ROOT_NS }
+    ROOT_NAMESPACES = {'xs': ROOT_NS}
 
     def get_type(self, name=None, xpath=None):
         if xpath is None:
@@ -613,7 +640,4 @@ class XsdSchema(XmlObject):
         elif len(result) > 1:
             raise Exception("Too many schema type definitions found for xpath '%s' (found %d)" \
                         % (xpath, len(result)))
-        return XsdType(result[0], context=self.context) # pass in namespaces
-
-
-
+        return XsdType(result[0], context=self.context)  # pass in namespaces
