@@ -27,9 +27,7 @@ __all__ = [
     'IntegerField', 'IntegerListField',
     'NodeField', 'NodeListField',
     'ItemField', 'SimpleBooleanField',
-# NOTE: DateField and DateListField are undertested and underdocumented. If
-#   you really need them, you should import them explicitly. Or even better,
-#   flesh them out so they can be properly released.
+    'DateTimeField', 'DateTimeListField',   
     'SchemaField',
 ]
 
@@ -150,8 +148,16 @@ class SimpleBooleanMapper(Mapper):
             return None
 
 
-class DateMapper(object):
+# TODO: DateMapper and Date fields
+
+class DateTimeMapper(object):
     XPATH = etree.XPath('string()')
+
+    def __init__(self, format=None, normalize=False):
+        self.format = format
+        if normalize:
+            self.XPATH = etree.XPath('normalize-space(string())')
+
     def to_python(self, node):
         if node is None:
             return None
@@ -163,15 +169,20 @@ class DateMapper(object):
             rep = rep[:-1]
         if rep[-6] in '+-': # strip tz
             rep = rep[:-6]
-        try:
-            dt = datetime.strptime(rep, '%Y-%m-%dT%H:%M:%S')
-        except ValueError, v:
-            # if initial format fails, attempt to parse with microseconds
-            dt = datetime.strptime(rep, '%Y-%m-%dT%H:%M:%S.%f')
+
+        if self.format is not None:
+            dt = datetime.strptime(rep, self.format)
+        else:
+            try:
+                dt = datetime.strptime(rep, '%Y-%m-%dT%H:%M:%S')
+            except ValueError, v:
+                # if initial format fails, attempt to parse with microseconds
+                dt = datetime.strptime(rep, '%Y-%m-%dT%H:%M:%S.%f')
         return dt
 
     def to_xml(self, dt):
-        # NOTE: untested!  this is probably close to what we need, but should be tested
+        if self.format is not None:
+            return unicode(dt.strftime(self.format))
         return unicode(dt.isoformat())
 
 
@@ -883,42 +894,76 @@ class SimpleBooleanField(Field):
 
 
 
-class DateField(Field):
+class DateTimeField(Field):
+    """
+    Map an XPath expression to a single Python
+    :class:`datetime.datetime`. If the XPath expression evaluates to
+    an empty :class:`NodeList`, a :class:`DateTimeField` evaluates to
+    `None`.
 
-    """Map an XPath expression to a single Python `datetime.datetime`. If
-    the XPath expression evaluates to an empty NodeList, a DateField evaluates
-    to `None`.
+    :param format: optional date-time format.  Used with
+	:meth:`datetime.datetime.strptime` and
+	:meth:`datetime.datetime.strftime` to convert between XML text
+	and Python :class:`datetime.datetime` objects.  If no format
+	is specified, XML dates are converted from full ISO date time
+	format, with or without microseconds, and dates are written
+	out to XML in ISO format via
+	:meth:`datetime.datetime.isoformat`.
+
+    :param normalize: optional parameter to indicate string contents
+        should have whitespace normalized before converting to
+        :class:`~datetime.datetime`.  By default, no normalization is
+        done.
+
+    For example, given the field definition::
+
+      last_update = DateField('last_update', format="%d-%m-%Y %H:%M:%S",
+      	  normalize=True)
+
+    and the XML::
+
+      <last_update>
+   	  21-04-2012 00:00:00
+      </last_update>
+
+    accessing the field would return::
+
+      >>> myobj.last_update
+      datetime.datetime(2012, 4, 21, 0, 0)
 
-    .. WARNING::
-       DateField processing is minimal, undocumented, and liable to change.
-       It is not part of any official release. Use it at your own risk.
     """
 
-    def __init__(self, xpath, *args, **kwargs):
-        super(DateField, self).__init__(xpath,
+    def __init__(self, xpath, format=None, normalize=False, *args, **kwargs):
+        super(DateTimeField, self).__init__(xpath,
                 manager = SingleNodeManager(),
-                mapper = DateMapper(), *args, **kwargs)
+                mapper = DateTimeMapper(format=format, normalize=normalize), *args, **kwargs)
 
 
-class DateListField(Field):
-
-    """Map an XPath expression to a list of Python `datetime.datetime`
-    objects. If the XPath expression evaluates to an empty NodeList, a
-    DateListField evaluates to an empty list.
-
-    .. WARNING::
-       DateListField processing is minimal, undocumented, and liable to
-       change. It is not part of any official release. Use it at your own
-       risk.
+class DateTimeListField(Field):
+    """
+    Map an XPath expression to a list of Python
+    :class:`datetime.datetime` objects. If the XPath expression
+    evaluates to an empty :class:`NodeList`, a
+    :class:`DateTimeListField` evaluates to an empty list.  Date
+    formatting is as described in :class:`DateTimeField`.
 
     Actual return type is :class:`~eulxml.xmlmap.fields.NodeList`, which can be
     treated like a regular Python list, and includes set and delete functionality.
+
+    :param format: optional date-time format.  See
+        :class:`DateTimeField` for more details.
+
+    :param normalize: optional parameter to indicate string contents
+        should have whitespace normalized before converting to
+        :class:`~datetime.datetime`.  By default, no normalization is
+        done.
+
     """
 
-    def __init__(self, xpath, *args, **kwargs):
-        super(DateListField, self).__init__(xpath,
+    def __init__(self, xpath, format=None, normalize=False, *args, **kwargs):
+        super(DateTimeListField, self).__init__(xpath,
                 manager = NodeListManager(),
-                mapper = DateMapper(), *args, **kwargs)
+                mapper = DateTimeMapper(format=format, normalize=normalize), *args, **kwargs)
 
 
 class NodeField(Field):
